//
//  ContentView.swift
//  AspectRatioDemo
//
//  Created by Gabriel Theodoropoulos.
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State private var aspectRatioValue: CGFloat = 16/9
    
    var body: some View {
        // MARK: - Displaying an image without applying the aspectRatio modifier
        // Image with frame modifier only.
//        Image("sample-image")
//            .frame(width: 300, height: 300)
        
        // Image with resizable and frame modifiers.
//        Image("sample-image")
//            .resizable()
//            .frame(width: 300, height: 300)
        
        // Image with resizable modifier only.
//        Image("sample-image")
//            .resizable()
        
        
        // MARK: - The fit content mode
        Image("sample-image")
            .resizable()
            .aspectRatio(contentMode: .fit)
        
        
        // MARK: - The fill content mode
//        Image("sample-image")
//            .resizable()
//            .aspectRatio(contentMode: .fill)
                
        
        // MARK: - Fit and fill content modes side by side
//        VStack(spacing: 40) {
//            Image("sample-image")
//                .resizable()
//                .aspectRatio(contentMode: .fit)
//                .frame(width: 300, height: 300)
//                .border(Color.blue, width: 4)
//            
//            Image("sample-image")
//                .resizable()
//                .aspectRatio(contentMode: .fill)
//                .frame(width: 300, height: 300)
//                .border(Color.blue, width: 4)
//        }
        
        
        // MARK: - Fit and fill content modes side by side with clipped() modifier
//        VStack(spacing: 40) {
//            Image("sample-image")
//                .resizable()
//                .aspectRatio(contentMode: .fit)
//                .frame(width: 300, height: 300)
//                .border(Color.blue, width: 4)
//            
//            Image("sample-image")
//                .resizable()
//                .aspectRatio(contentMode: .fill)
//                .frame(width: 300, height: 300)
//                .clipped()
//                .border(Color.blue, width: 4)
//        }
        
        
        // MARK: - Aspect ratio in color view
//        Color.indigo
//            .aspectRatio(4/3, contentMode: .fit)
//            .frame(width: 300, height: 300)
//            .border(.red, width: 4)
        
        
        // MARK: - Multiple aspect ratio values
//        VStack {
//            Color.indigo
//                .aspectRatio(4/3, contentMode: .fit)
//                .frame(width: 250, height: 250)
//                .border(.red, width: 4)
//
//            Color.indigo
//                .aspectRatio(21/9, contentMode: .fit)
//                .frame(width: 250, height: 250)
//                .border(.red, width: 4)
//
//            Color.indigo
//                .aspectRatio(0.5, contentMode: .fit)
//                .frame(width: 250, height: 250)
//                .border(.red, width: 4)
//        }
        
        
        // MARK: - Animated aspect ratio value
//        Color.indigo
//            .aspectRatio(aspectRatioValue, contentMode: .fit)
//            .frame(width: 300, height: 300)
//            .border(.red, width: 4)
//            .onAppear {
//                withAnimation(.smooth.repeatForever()) {
//                    aspectRatioValue = aspectRatioValue == 16/9 ? 1/2 : 16/9
//                }
//            }
    }
}

#Preview {
    ContentView()
}
